Subset a GWAS dataset to variants within a specified genomic region.
Examples
data(example_gwas)
mhc <- filter_region(example_gwas, chr = 6, start = 25e6, end = 34e6)
Subset a GWAS dataset to variants within a specified genomic region.
data(example_gwas)
mhc <- filter_region(example_gwas, chr = 6, start = 25e6, end = 34e6)